package com.ruoyi.project.ehs.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.project.ehs.mapper.TRcfileMapper;
import com.ruoyi.project.ehs.domain.TRcfile;
import com.ruoyi.project.ehs.service.ITRcfileService;

/**
 * RC附件Service业务层处理
 *
 * @author ssy
 * @date 2023-10-24
 */
@Service
public class TRcfileServiceImpl implements ITRcfileService
{
    @Autowired
    private TRcfileMapper tRcfileMapper;

    /**
     * 查询RC附件
     *
     * @param id RC附件ID
     * @return RC附件
     */
    @Override
    public TRcfile selectTRcfileById(Long id)
    {
        return tRcfileMapper.selectTRcfileById(id);
    }

    /**
     * 查询RC附件列表
     *
     * @param tRcfile RC附件
     * @return RC附件
     */
    @Override
    public List<TRcfile> selectTRcfileList(TRcfile tRcfile)
    {
        return tRcfileMapper.selectTRcfileList(tRcfile);
    }

    /**
     * 新增RC附件
     *
     * @param tRcfile RC附件
     * @return 结果
     */
    @Override
    public int insertTRcfile(TRcfile tRcfile)
    {
        return tRcfileMapper.insertTRcfile(tRcfile);
    }

    /**
     * 修改RC附件
     *
     * @param tRcfile RC附件
     * @return 结果
     */
    @Override
    public int updateTRcfile(TRcfile tRcfile)
    {
        return tRcfileMapper.updateTRcfile(tRcfile);
    }

    /**
     * 批量删除RC附件
     *
     * @param ids 需要删除的RC附件ID
     * @return 结果
     */
    @Override
    public int deleteTRcfileByIds(Long[] ids)
    {
        return tRcfileMapper.deleteTRcfileByIds(ids);
    }

    /**
     * 删除RC附件信息
     *
     * @param id RC附件ID
     * @return 结果
     */
    @Override
    public int deleteTRcfileById(Long id)
    {
        return tRcfileMapper.deleteTRcfileById(id);
    }
}
